==> haskell-skylighting-0.7.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.7.3
id: skylighting-0.7.3-7pxXv0RvR1lK0kmbF4Sn4K
key: skylighting-0.7.3-7pxXv0RvR1lK0kmbF4Sn4K
license: GPL-2.0-only
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.
category: Text
abi: 5dc43b4e4b5b7c0bf9c93e5954e70814
exposed: True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq:Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Default Skylighting.Syntax.Diff
                Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
                Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
                Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
                Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
                Skylighting.Syntax.Email Skylighting.Syntax.Erlang
                Skylighting.Syntax.Fasm Skylighting.Syntax.Fortran
                Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
                Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
                Skylighting.Syntax.Go Skylighting.Syntax.Hamlet
                Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
                Skylighting.Syntax.Html Skylighting.Syntax.Idris
                Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
                Skylighting.Syntax.Java Skylighting.Syntax.Javadoc
                Skylighting.Syntax.Javascript Skylighting.Syntax.Json
                Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
                Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
                Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
                Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
                Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
                Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
                Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
                Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
                Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
                Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
                Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
                Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
                Skylighting.Syntax.Nasm Skylighting.Syntax.Noweb
                Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
                Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
                Skylighting.Syntax.Opencl Skylighting.Syntax.Pascal
                Skylighting.Syntax.Perl Skylighting.Syntax.Php
                Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
                Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
                Skylighting.Syntax.Prolog Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.SqlMysql
                Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Sql
                Skylighting.Syntax.Tcl Skylighting.Syntax.Tcsh
                Skylighting.Syntax.Texinfo Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
import-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-0.7.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-0.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skylighting-0.7.3
hs-libraries: HSskylighting-0.7.3-7pxXv0RvR1lK0kmbF4Sn4K
depends:
    base-4.11.1.0 skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq
    mtl-2.2.2 text-1.2.3.0 binary-0.8.5.1 bytestring-0.10.8.2
    directory-1.3.1.5 filepath-1.4.2
    aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9 containers-0.5.11.0
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE
    regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             skylighting-core-0.7.3-2Ms8jjqgsMq4oRHmVbugkq=6596f3a4c3bf8a15f0dbc4865db7a273
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P=be88e93269229a8af3cc92dec8098755
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9=c6e80aabf69818c42063522c698c33e8
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE=a833f5ee389bbe28de815ccdd9dc961e
             regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv=cd8a991f2d7b99d9774d2361006f4ec4
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.7.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.7.3
id: skylighting-0.7.3-EM8XcNEGeIoLa4RPxm0Qr3
key: skylighting-0.7.3-EM8XcNEGeIoLa4RPxm0Qr3
license: GPL-2.0-only
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.
category: Text
abi: 1a977a699c6c1604aaffbfcdf0f1020e
exposed: True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI:Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Default Skylighting.Syntax.Diff
                Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
                Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
                Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
                Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
                Skylighting.Syntax.Email Skylighting.Syntax.Erlang
                Skylighting.Syntax.Fasm Skylighting.Syntax.Fortran
                Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
                Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
                Skylighting.Syntax.Go Skylighting.Syntax.Hamlet
                Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
                Skylighting.Syntax.Html Skylighting.Syntax.Idris
                Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
                Skylighting.Syntax.Java Skylighting.Syntax.Javadoc
                Skylighting.Syntax.Javascript Skylighting.Syntax.Json
                Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
                Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
                Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
                Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
                Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
                Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
                Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
                Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
                Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
                Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
                Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
                Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
                Skylighting.Syntax.Nasm Skylighting.Syntax.Noweb
                Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
                Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
                Skylighting.Syntax.Opencl Skylighting.Syntax.Pascal
                Skylighting.Syntax.Perl Skylighting.Syntax.Php
                Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
                Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
                Skylighting.Syntax.Prolog Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.SqlMysql
                Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Sql
                Skylighting.Syntax.Tcl Skylighting.Syntax.Tcsh
                Skylighting.Syntax.Texinfo Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
import-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-0.7.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-0.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skylighting-0.7.3
hs-libraries: HSskylighting-0.7.3-EM8XcNEGeIoLa4RPxm0Qr3
depends:
    base-4.11.1.0 skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI
    mtl-2.2.2 text-1.2.3.0 binary-0.8.5.1 bytestring-0.10.8.2
    directory-1.3.1.5 filepath-1.4.2
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9 containers-0.5.11.0
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE
    regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             skylighting-core-0.7.3-3k1fxeTizltGzid77cUrvI=40cd9a05bb176bebcc6e46d8859eaeed
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P=be88e93269229a8af3cc92dec8098755
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-html-0.9.1.1-crQaAXRkXt2XDlbzXFON9=c6e80aabf69818c42063522c698c33e8
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE=a833f5ee389bbe28de815ccdd9dc961e
             regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv=cd8a991f2d7b99d9774d2361006f4ec4
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
